[network-manager-applet/NMA_0_8] editor: use "Save" instead of "Apply" for connection saving button (bgo #625166)



commit b88dbcf9775b391009a6935ea3ba91055d2f116f
Author: JiÅ?í KlimeÅ¡ <jklimes redhat com>
Date:   Tue Oct 12 10:54:14 2010 +0200

    editor: use "Save" instead of "Apply" for connection saving button (bgo #625166)

 src/connection-editor/nm-connection-editor.c |    8 ++++----
 1 files changed, 4 insertions(+), 4 deletions(-)
---
diff --git a/src/connection-editor/nm-connection-editor.c b/src/connection-editor/nm-connection-editor.c
index 4bd2daa..59e7149 100644
--- a/src/connection-editor/nm-connection-editor.c
+++ b/src/connection-editor/nm-connection-editor.c
@@ -260,7 +260,7 @@ system_checkbutton_toggled_cb (GtkWidget *widget, NMConnectionEditor *editor)
 {
 	gboolean use_polkit = TRUE;
 
 	/* The only time the Apply button does not need to use polkit is when the
 	 * original connection scope was USER and the "system" checkbutton is
 	 * unchecked.
 	 */
@@ -409,16 +409,16 @@ nm_connection_editor_new (NMConnection *connection,
 	                  editor);
 
 	/* If this is a system connection that we can't ever modify,
 	 * set the editor's Apply button always insensitive.
 	 */
 	if (nm_connection_get_scope (connection) == NM_CONNECTION_SCOPE_SYSTEM) {
 		sensitive = editor->system_settings_can_modify;
 		use_polkit = TRUE;
 	}
 
-	editor->ok_button = ce_polkit_button_new (_("Apply"),
+	editor->ok_button = ce_polkit_button_new (_("Save"),
 	                                          _("Save any changes made to this connection."),
-	                                          _("Apply..."),
+	                                          _("Save..."),
 	                                          _("Authenticate to save this connection for all users of this machine."),
 	                                          GTK_STOCK_APPLY,
 	                                          settings,
@@ -260,7 +260,7 @@ system_checkbutton_toggled_cb (GtkWidget *widget, NMConnectionEditor *editor)
 	gboolean use_polkit = TRUE;
 
-	/* The only time the Apply button does not need to use polkit is when the
+	/* The only time the Save button does not need to use polkit is when the
 	 * original connection scope was USER and the "system" checkbutton is
 	 * unchecked.
@@ -409,16 +409,16 @@ nm_connection_editor_new (NMConnection *connection,
 
 	/* If this is a system connection that we can't ever modify,
-	 * set the editor's Apply button always insensitive.
+	 * set the editor's Save button always insensitive.
 	 */
 	if (nm_connection_get_scope (connection) == NM_CONNECTION_SCOPE_SYSTEM) {



[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]